@@ -1,6 +1,9 @@
 /// Endianness of a [processor](crate::Cpu).
-#[cfg_attr(feature = "serde", derive(serde::Deserialize, serde::Serialize))]
-#[cfg_attr(feature = "serde", serde(rename_all = "kebab-case"))]
+#[cfg_attr(
+    feature = "serde",
+    derive(serde::Deserialize, serde::Serialize),
+    serde(rename_all = "kebab-case")
+)]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum Endian {
     /// Little endian.
